import{aM as f,aN as i,aO as p,aP as b,aQ as m}from"./index-Drrpbg7e.js";function y(a,r){var s=-1,e=f(a)?Array(a.length):[];return i(a,function(n,t,u){e[++s]=r(n,t,u)}),e}function M(a,r){var s=b(a)?m:y;return s(a,p(r))}export{y as b,M as m};
