import{aT as o,aP as f,aU as y,aN as u,aO as d,aV as h}from"./index-Drrpbg7e.js";function b(a){return typeof a=="function"?a:o}function g(a,n){var r=f(a)?y:u;return r(a,b(n))}function p(a,n,r,e,t){return t(a,function(s,c,i){r=e?(e=!1,s):n(r,s,c,i)}),r}function R(a,n,r){var e=f(a)?h:p,t=arguments.length<3;return e(a,d(n),r,t,u)}export{b as c,g as f,R as r};
